ChangeLog
=========

1.0.0 (2015-09-25)
------------------

* Add generic ``scan_codes()`` function (which can scan multiple codes in the same image)
* Fix Python 2.6 tests
* Exclude tests from package


0.1.1 (2014-12-16)
------------------

* Minor fixes on Readme
* Include requirements-dev.txt in Manifest


0.1.0 (2014-12-12)
------------------

* First public version.
